@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,8 +39,6 @@ private:
     void save();
     void load();
     QCheckBox *mUseDefaultPixmap = nullptr;
-    QCheckBox *mUseLibravatar = nullptr;
-    QCheckBox *mFallbackGravatar = nullptr;
     QPushButton *mClearGravatarCache = nullptr;
     KPluralHandlingSpinBox *mGravatarCacheSize = nullptr;
 };
